@@ -3,16 +3,18 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 use strict;
 use warnings;
 
 use File::ShareDir qw(dist_dir);
 use List::Util qw(any);
-use Moo;
 use Music::Note;
 use Text::CSV_XS ();
+use Moo;
+use strictures 2;
+use namespace::clean;
 
 
 has chords => (
@@ -78,9 +80,9 @@ sub transform {
 sub _lowest_c {
     my ($pitches) = @_;
     my $lowest = 0;
-    for my $pitch (48, 60, 72) {
-        if (any { $_ == $pitch } @$pitches) {
-            $lowest = $pitch;
+    for my $c (48, 60, 72) {
+        if (any { $_ == $c } @$pitches) {
+            $lowest = $c;
             last;
         }
     }
@@ -122,7 +124,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
@@ -136,15 +138,15 @@ version 0.0301
   my $chord = $mcg->transform('D3', 'dim7', 0);
   # [41, 47, 50, 56]
 
+  # MIDI:
+  #$score->n('wn', @$chord);
+
   my $voicings = $mcg->voicings('dim7');
   # [ [51, 57, 60, 66], [48, 54, 57, 63, 66] ]
 
   $voicings = $mcg->voicings('dim7', 'ISO');
   # [ [D#3 A3 C4 F#4], [C3 F#3 A3 D#4 F#4] ]
 
-  # MIDI:
-  #$score->n('wn', @$chord);
-
 =head1 DESCRIPTION
 
 C<MIDI::Chord::Guitar> provides MIDI pitches for common chord voicings
@@ -163,7 +165,7 @@ of an C<E A D G B E> tuned guitar.
 
 Computed attribute available after construction.
 
-The known chord names are as follows:
+The known chord names in the key of C are as follows:
 
   '' (major)
   aug
